@@ -1,7 +1,5 @@
-import argparse
 import logging
 import os
-import sys
 
 from zipfile import ZipFile
 
