@@ -9,9 +9,9 @@ logging.basicConfig(level=logging.INFO)
 import http.client
 http.client.HTTPConnection.debuglevel = 1
 
+logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
-
 requests_log = logging.getLogger("requests.packages.urllib3")
 requests_log.setLevel(logging.DEBUG)
 requests_log.propagate = True
@@ -29,8 +29,7 @@ def get_max_tag(tag, other_tag):
     return tag if (vers > other_vers) else other_tag
 
 
-
-class CattleHead():
+class CattleHead:
 
     _icon_dict = {
         'manual': 'https://nasa-pds.github.io/pdsen-corral/images/manual.png',
@@ -41,7 +40,7 @@ class CattleHead():
         'feedback': 'https://nasa-pds.github.io/pdsen-corral/images/feedback.png'
     }
 
-    def __init__(self, name, github_path, version=None, dev=False, token=None):
+    def __init__(self, name, github_path, version=None, type=None, dev=False, token=None):
         logger.info(f'create cattleHead {name}, {github_path}')
         self._name = name
         self._github_path = github_path
@@ -51,7 +50,7 @@ class CattleHead():
         gh = github3.login(token=self._token)
         self._repo = gh.repository(self._org, self._repo_name)
         self._description = self._repo.description
-        self._changelog_url = f'https://github.com/{self._org}/{self._repo_name}/blob/master/CHANGELOG.md'
+        self._changelog_url = f'https://github.com/{self._org}/{self._repo_name}/blob/main/CHANGELOG.md'
         self._changelog_signets = self._get_changelog_signet()
         self._dev = dev
 
@@ -63,8 +62,20 @@ class CattleHead():
         else:
             self._update = None
 
+        self._type = type
+
         self.rst_doc = None
 
+    @property
+    def type(self):
+        """'type' property."""
+        return self._type
+
+    @property
+    def repo_name(self):
+        """'repo_name' property, for example 'pds-doi-service'"""
+
+
     def set_rst(self, d):
         self.rst_doc = d
 
@@ -126,16 +137,11 @@ class CattleHead():
         return f'{self._github_path}/releases/tag/{self._version}'
 
     def _get_manual_link(self):
-        if self._version_name:
-            url = f'https://{self._org}.github.io/{self._repo_name}/{self._version_name}'
-            if self._reachable(url):
-                return url
-            elif self._version_name[0] == 'v':
-                url = f'https://{self._org}.github.io/{self._repo_name}/{self._version_name[1:]}'
-                if self._reachable(url):
-                    return url
-
-        return f'https://{self._org}.github.io/{self._repo_name}'
+        url = f'https://{self._org}.github.io/{self._repo_name}/'
+        if self._reachable(url):
+            return url
+        else:
+            return f'https://github.com/{self._org}/{self._repo_name}'
 
 
     def _get_changelog_link(self):
@@ -148,7 +154,7 @@ class CattleHead():
             return "https://www.gnupg.org/gph/en/manual/r1943.html"
 
     def _get_requirements_link(self):
-        url = f'https://github.com/{self._org}/{self._repo_name}/blob/master/docs/requirements/{self._version_name}/REQUIREMENTS.md'
+        url = f'https://github.com/{self._org}/{self._repo_name}/blob/main/docs/requirements/{self._version_name}/REQUIREMENTS.md'
 
         if self._version_name and self._reachable(url):
             return url
@@ -156,7 +162,7 @@ class CattleHead():
             return None
 
     def _get_license_link(self):
-        return f'https://raw.githubusercontent.com/NASA-PDS/{self._repo_name}/master/LICENSE.txt'
+        return f'https://raw.githubusercontent.com/NASA-PDS/{self._repo_name}/main/LICENSE.txt'
 
     def _get_feedback_link(self):
         return f'{self._github_path}/issues/new/choose'
